@@ -32,7 +32,7 @@ namespace Edirol {
 class EdirolFa101Device : public BeBoB::Device {
 public:
     EdirolFa101Device( DeviceManager& d,
-                       std::auto_ptr<ConfigRom>( configRom ));
+                       ffado_smartptr<ConfigRom>( configRom ));
     virtual ~EdirolFa101Device();
 
     virtual ClockSourceVector getSupportedClockSources();
