@@ -176,13 +176,11 @@ ConfigRom::initialize()
                 ( void* )CSR1212_TEXTUAL_DESCRIPTOR_LEAF_DATA( m_vendorNameKv ),
                 len );
 
-    while ((buf + len - 1) == '\0') {
-            len--;
+        while (*(buf + len - 1) == '\0') {
+                len--;
         }
-        // \todo XXX seems a bit strage to do this but the nodemgr.c code does
-        // it. try to figure out why this is needed (or not)
-    buf[len++] = ' ';
-    buf[len] = '\0';
+        // Ensure vendor string is null terminated
+        buf[len] = '\0';
 
 
         debugOutput( DEBUG_LEVEL_VERBOSE, "Vendor name: '%s'\n", buf );
@@ -195,13 +193,11 @@ ConfigRom::initialize()
         memcpy( buf,
                 ( void* )CSR1212_TEXTUAL_DESCRIPTOR_LEAF_DATA( m_modelNameKv ),
                 len );
-    while ((buf + len - 1) == '\0') {
-            len--;
+        while (*(buf + len - 1) == '\0') {
+                len--;
         }
-        // \todo XXX for edirol fa-66 it seems somehow broken. see above
-        // todo as well.
-    buf[len++] = ' ';
-    buf[len] = '\0';
+        // Ensure model name string is null terminated
+        buf[len] = '\0';
 
         debugOutput( DEBUG_LEVEL_VERBOSE, "Model name: '%s'\n", buf);
         m_modelName = buf;
@@ -527,7 +523,7 @@ bool
 ConfigRom::updatedNodeId()
 {
     debugOutput( DEBUG_LEVEL_VERBOSE, 
-                 "Checking for updated node id for device with GUID 0x%016"PRIX64"...\n",
+                 "Checking for updated node id for device with GUID 0x%016" PRIX64 "...\n",
                  getGuid());
 
     struct csr1212_csr* csr = NULL;
@@ -558,14 +554,14 @@ ConfigRom::updatedNodeId()
             | CSR1212_BE32_TO_CPU(csr->bus_info_data[4]);
 
         debugOutput( DEBUG_LEVEL_VERBOSE,
-                        " Node has GUID 0x%016"PRIX64"\n",
+                        " Node has GUID 0x%016" PRIX64 "\n",
                         guid);
 
         if ( guid == getGuid() ) {
             debugOutput( DEBUG_LEVEL_VERBOSE, "GUID matches ours\n");
             if ( nodeId != getNodeId() ) {
                 debugOutput( DEBUG_LEVEL_VERBOSE,
-                             "Device with GUID 0x%016"PRIX64" changed node id "
+                             "Device with GUID 0x%016" PRIX64 " changed node id "
                              "from %d to %d\n",
                              getGuid(),
                              getNodeId(),
@@ -573,7 +569,7 @@ ConfigRom::updatedNodeId()
                 m_nodeId = nodeId;
             } else {
                 debugOutput( DEBUG_LEVEL_VERBOSE,
-                             "Device with GUID 0x%016"PRIX64" kept node id %d\n",
+                             "Device with GUID 0x%016" PRIX64 " kept node id %d\n",
                              getGuid(),
                              getNodeId());
             }
@@ -590,7 +586,7 @@ ConfigRom::updatedNodeId()
     }
 
     debugOutput( DEBUG_LEVEL_VERBOSE,
-                 "Device with GUID 0x%016"PRIX64" could not be found on "
+                 "Device with GUID 0x%016" PRIX64 " could not be found on "
                  "the bus anymore (removed?)\n",
                  getGuid() );
     m_nodeId = INVALID_NODE_ID;
@@ -603,7 +599,7 @@ ConfigRom::printConfigRomDebug() const
     using namespace std;
     debugOutput(DEBUG_LEVEL_NORMAL, "Config ROM\n" );
     debugOutput(DEBUG_LEVEL_NORMAL, "\tCurrent Node Id:\t%d\n",       getNodeId() );
-    debugOutput(DEBUG_LEVEL_NORMAL, "\tGUID:\t\t\t0x%016"PRIX64"\n",       getGuid());
+    debugOutput(DEBUG_LEVEL_NORMAL, "\tGUID:\t\t\t0x%016" PRIX64 "\n",       getGuid());
     debugOutput(DEBUG_LEVEL_NORMAL, "\tVendor Name:\t\t%s\n",         getVendorName().c_str() );
     debugOutput(DEBUG_LEVEL_NORMAL, "\tModel Name:\t\t%s\n",          getModelName().c_str() );
     debugOutput(DEBUG_LEVEL_NORMAL, "\tNode Vendor ID:\t\t0x%06x\n",  getNodeVendorId() );
@@ -624,7 +620,7 @@ ConfigRom::printConfigRom() const
     using namespace std;
     printMessage("Config ROM\n" );
     printMessage("\tCurrent Node Id:\t%d\n",       getNodeId() );
-    printMessage("\tGUID:\t\t\t0x%016"PRIX64"\n",       getGuid());
+    printMessage("\tGUID:\t\t\t0x%016" PRIX64 "\n",       getGuid());
     printMessage("\tVendor Name:\t\t%s\n",         getVendorName().c_str() );
     printMessage("\tModel Name:\t\t%s\n",          getModelName().c_str() );
     printMessage("\tNode Vendor ID:\t\t0x%06x\n",  getNodeVendorId() );
