@@ -64,7 +64,7 @@ Configuration::openFile(std::string filename, enum eFileMode mode)
                 delete c;
                 return false;
             } catch (ParseException& e) {
-                debugWarning("Could not parse file: %s\n", filename.c_str());
+                debugWarning("Could not parse file: %s\nError: %s, Line: %i, What: %s", filename.c_str(), e.getError(), e.getLine(), e.what());
                 delete c;
                 return false;
             } catch (...) {
@@ -189,7 +189,7 @@ Configuration::ConfigFile::showSetting(libconfig::Setting &s, std::string prefix
         {
             int64_t i = s;
             debugOutput(DEBUG_LEVEL_NORMAL,
-                        "  %s%s = %"PRId64" (0x%016"PRIX64")\n",
+                        "  %s%s = %" PRId64 " (0x%016" PRIX64 ")\n",
                         prefix.c_str(), s.getName(), i, i);
         }
         break;
@@ -258,7 +258,7 @@ Configuration::getValueForSetting(std::string path, int64_t &ref)
         Setting::Type t = s->getType();
         if(t == Setting::TypeInt64) {
             ref = *s;
-            debugOutput(DEBUG_LEVEL_VERY_VERBOSE, "path '%s' has value %"PRId64"\n", path.c_str(), ref);
+            debugOutput(DEBUG_LEVEL_VERY_VERBOSE, "path '%s' has value %" PRId64 "\n", path.c_str(), ref);
             return true;
         } else {
             debugWarning("path '%s' has wrong type\n", path.c_str());
