@@ -580,15 +580,15 @@ Device::read_device_mixer_settings(FF_software_settings_t *dsettings)
         return -1;
 
     i = read_flash(addr, (quadlet_t *)(vbuf), RME_FF_FLASH_MIXER_ARRAY_SIZE/4);
-    debugOutput(DEBUG_LEVEL_VERBOSE, "read_flash(%"PRId64") returned %d\n", addr, i);
+    debugOutput(DEBUG_LEVEL_VERBOSE, "read_flash(%" PRId64 ") returned %d\n", addr, i);
 
     addr += RME_FF_FLASH_MIXER_ARRAY_SIZE;
     i = read_flash(addr, (quadlet_t *)(pbuf), RME_FF_FLASH_MIXER_ARRAY_SIZE/4);
-    debugOutput(DEBUG_LEVEL_VERBOSE, "read_flash(%"PRId64") returned %d\n", addr, i);
+    debugOutput(DEBUG_LEVEL_VERBOSE, "read_flash(%" PRId64 ") returned %d\n", addr, i);
 
     addr += RME_FF_FLASH_MIXER_ARRAY_SIZE;
     i = read_flash(addr, (quadlet_t *)obuf, RME_FF_FLASH_SECTOR_SIZE_QUADS);
-    debugOutput(DEBUG_LEVEL_VERBOSE, "read_flash(%"PRId64") returned %d\n", addr, i);
+    debugOutput(DEBUG_LEVEL_VERBOSE, "read_flash(%" PRId64 ") returned %d\n", addr, i);
 
     for (out=0; out<nch/2; out++) {
         for (in=0; in<nch; in++) {
@@ -608,8 +608,10 @@ Device::read_device_mixer_settings(FF_software_settings_t *dsettings)
     // indicates MIDI control is active while [31] is a submix number.
     // It's suspected that neither of these are used by the device directly,
     // and that these elements are just a convenient place for computer
-    // control applications to store things.
-    for (out=0; out<30; out++) {
+    // control applications to store things.  FFADO does not make use
+    // of these.  nch is assumed to be <= RME_FF800_MAX_CHANNELS (28),
+    // the size of the output_faders[] array.
+    for (out=0; out<nch; out++) {
       dsettings->output_faders[out] = flashvol2fader(obuf[out]);
     }
 
@@ -664,7 +666,7 @@ Device::write_device_mixer_settings(FF_software_settings_t *dsettings)
             shadow[0x1f80/4+out] = dsettings->output_faders[out];
         }
         i = write_flash(addr, shadow, RME_FF800_FLASH_MIXER_SHADOW_SIZE/4);
-        debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%"PRId64") returned %d\n", addr, i);
+        debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%" PRId64 ") returned %d\n", addr, i);
         addr = RME_FF800_FLASH_MIXER_VOLUME_ADDR;
     }
 
@@ -688,20 +690,20 @@ Device::write_device_mixer_settings(FF_software_settings_t *dsettings)
     // Elements 30 and 31 of obuf[] are not output fader values.  See
     // comments in read_device_mixer_settings().
     memset(obuf, 0, sizeof(obuf));
-    for (out=0; out<30; out++) {
+    for (out=0; out<nch; out++) {
       obuf[out] = fader2flashvol(dsettings->output_faders[out]);
     }
 
     i = write_flash(addr, (quadlet_t *)(vbuf), RME_FF_FLASH_MIXER_ARRAY_SIZE/4);
-    debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%"PRId64") returned %d\n", addr, i);
+    debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%" PRId64 ") returned %d\n", addr, i);
 
     addr += RME_FF_FLASH_MIXER_ARRAY_SIZE;
     i = write_flash(addr, (quadlet_t *)(pbuf), RME_FF_FLASH_MIXER_ARRAY_SIZE/4);
-    debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%"PRId64") returned %d\n", addr, i);
+    debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%" PRId64 ") returned %d\n", addr, i);
 
     addr += RME_FF_FLASH_MIXER_ARRAY_SIZE;
     i = write_flash(addr, (quadlet_t *)obuf, RME_FF_FLASH_SECTOR_SIZE_QUADS);
-    debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%"PRId64") returned %d\n", addr, i);
+    debugOutput(DEBUG_LEVEL_VERBOSE, "write_flash(%" PRId64 ") returned %d\n", addr, i);
 
     return 0;
 }
