@@ -24,8 +24,9 @@
 
 from ffado.config import * #FFADO_VERSION, FFADO_DBUS_SERVER, FFADO_DBUS_BASEPATH
 
-from PyQt4.QtGui import QFrame, QWidget, QTabWidget, QVBoxLayout, QMainWindow, QIcon, QAction, qApp, QStyleOptionTabWidgetFrame, QFileDialog
-from PyQt4.QtCore import QTimer
+# from PyQt4.QtGui import QFrame, QWidget, QTabWidget, QVBoxLayout, QMainWindow, QIcon, QAction, qApp, QStyleOptionTabWidgetFrame, QFileDialog
+# from PyQt4.QtCore import QTimer, pyqtSignal
+from ffado.import_pyqt import *
 
 from ffado.dbus_util import *
 from ffado.registration import *
@@ -35,7 +36,9 @@ from ffado.configuration import *
 from ffado.mixer.globalmixer import GlobalMixer
 from ffado.mixer.dummy import Dummy
 
+import sys
 import time
+import importlib
 
 import logging
 log = logging.getLogger('panelmanager')
@@ -83,6 +86,7 @@ class OwnTabWidget(QTabWidget):
             self.tabBar().show()
 
 class PanelManager(QWidget):
+    connectionLost = pyqtSignal(name='connectionLost')
     def __init__(self, parent, devmgr=None):
         QWidget.__init__(self, parent)
         self.setObjectName("PanelManager")
@@ -122,7 +126,7 @@ class PanelManager(QWidget):
         self.devmgr.registerDestroyedCallback(self.devmgrDestroyed)
         # create a timer to poll the panels
         self.polltimer = QTimer()
-        self.connect( self.polltimer, SIGNAL('timeout()'), self.pollPanels )
+        self.polltimer.timeout.connect(self.pollPanels)
         self.polltimer.start( POLL_SLEEP_TIME_MSEC )
 
         # create a timer to initialize the panel after the main form is shown
@@ -131,7 +135,7 @@ class PanelManager(QWidget):
 
         # live check timer
         self.alivetimer = QTimer()
-        QObject.connect( self.alivetimer, SIGNAL('timeout()'), self.commCheck )
+        self.alivetimer.timeout.connect(self.commCheck)
         self.alivetimer.start( 2000 )
 
     def count(self):
@@ -211,21 +215,26 @@ class PanelManager(QWidget):
                 w = self.panels[panel]
                 del self.panels[panel]
                 w.deleteLater()
-            self.emit(SIGNAL("connectionLost"))
+            self.connectionLost.emit()
 
     def removePanel(self, guid):
-        print "Removing widget for device" + guid
+        print( "Removing widget for device" + guid )
         w = self.panels[guid]
         del self.panels[guid] # remove from the list
         idx = self.tabs.indexOf(w)
         self.tabs.removeTab(idx)
         w.deleteLater()
+        self.parent.editmenu.removeAction(self.parent.devices[guid])
+        self.parent.devices.pop(guid, None)
 
     def addPanel(self, idx):
         path = self.devmgr.getDeviceName(idx)
         log.debug("Adding device %d: %s" % (idx, path))
 
-        cfgrom = ConfigRomInterface(FFADO_DBUS_SERVER, FFADO_DBUS_BASEPATH+'/DeviceManager/'+path)
+        if ffado.config.bypassdbus:
+            cfgrom = ConfigRomInterface(FFADO_DBUS_SERVER, path)
+        else:
+            cfgrom = ConfigRomInterface(FFADO_DBUS_SERVER, FFADO_DBUS_BASEPATH+'/DeviceManager/'+path)
         vendorId = cfgrom.getVendorId()
         modelId = cfgrom.getModelId()
         unitVersion = cfgrom.getUnitVersion()
@@ -235,30 +244,31 @@ class PanelManager(QWidget):
         log.debug(" Found (%s, %X, %X) %s %s" % (str(guid), vendorId, modelId, vendorName, modelName))
 
         # check whether this has already been registered at ffado.org
-        reg = ffado_registration(FFADO_VERSION, int(guid, 16),
-                                     vendorId, modelId,
-                                     vendorName, modelName)
-        reg.check_for_registration()
+        if not ffado.config.bypassdbus:
+            reg = ffado_registration(FFADO_VERSION, int(guid, 16),
+                                         vendorId, modelId,
+                                         vendorName, modelName)
+            reg.check_for_registration()
 
-        # The MOTU devices use unitVersion to differentiate models.  For the
-        # moment though we don't need to know precisely which model we're
-        # using beyond it being a pre-mark3 (modelId=0) or mark3 (modelId=1) 
-        # device.
-        if vendorId == 0x1f2:
-            # All MOTU devices with a unit version of 0x15 or greater are
-            # mark3 devices
-            if (unitVersion >= 0x15):
-                modelId = 0x00000001
-            else:
-                modelId = 0x00000000
+            # The MOTU devices use unitVersion to differentiate models.  For
+            # the moment though we don't need to know precisely which model
+            # we're using beyond it being a pre-mark3 (modelId=0) or mark3
+            # (modelId=1) device.
+            if vendorId == 0x1f2:
+                # All MOTU devices with a unit version of 0x15 or greater are
+                # mark3 devices
+                if (unitVersion >= 0x15):
+                    modelId = 0x00000001
+                else:
+                    modelId = 0x00000000
 
-        # The RME devices use unitVersion to differentiate models. 
-        # Therefore in the configuration file we use the config file's
-        # modelid field to store the unit version.  As a result we must
-        # override the modelId with the unit version here so the correct
-        # configuration file entry (and hense mixer widget) is identified.
-        if vendorId == 0xa35:
-            modelId = unitVersion;
+            # The RME devices use unitVersion to differentiate models. 
+            # Therefore in the configuration file we use the config file's
+            # modelid field to store the unit version.  As a result we must
+            # override the modelId with the unit version here so the correct
+            # configuration file entry (and hense mixer widget) is identified.
+            if vendorId == 0xa35:
+                modelId = unitVersion;
 
         dev = self.devices.getDeviceById( vendorId, modelId )
 
@@ -293,13 +303,17 @@ class PanelManager(QWidget):
         #
         # Specific (or dummy) mixer widgets get loaded in the following
         #
+        found = False
         if 'mixer' in dev and dev['mixer'] != None:
             mixerapp = dev['mixer']
-            exec( """
-import ffado.mixer.%s
-mixerwidget = ffado.mixer.%s.%s( w )
-""" % (mixerapp.lower(), mixerapp.lower(), mixerapp) )
-        else:
+            try:
+                mixer_module = importlib.import_module("ffado.mixer.%s" % mixerapp.lower())
+                mixerwidget = getattr(mixer_module, mixerapp)(w)
+                found = True
+            except ImportError:
+                log.debug("bypassdbus set, %s module not available: ignored" % mixerapp.lower())
+
+        if not found:
             mixerwidget = Dummy( w )
             mixerapp = modelName+" (Dummy)"
 
@@ -322,7 +336,14 @@ mixerwidget = ffado.mixer.%s.%s( w )
         else:
             title = mixerapp
 
-        globalmixer.setName(title)
+        mixer_icon = UIDIR + '/ffado/mixer/' + vendorName.replace(" ", "_").lower() + '.png'
+        if os.path.exists(mixer_icon) :
+            globalmixer.lblName.setPixmap(QPixmap(mixer_icon))
+            globalmixer.lblName.setToolTip(title)
+            globalmixer.lblName.show()
+        else :
+            globalmixer.setName(title)
+
         self.tabs.addTab( w, title )
         self.panels[guid] = w
 
@@ -340,6 +361,22 @@ mixerwidget = ffado.mixer.%s.%s( w )
           w.smixReadSetgs = mixerwidget.readSettings
           self.parent.openaction.setEnabled(True)
 
+        self.parent.devices[guid] = QAction(QIcon.fromTheme("audio-card"), str(title), self.parent)
+        # Ensure a standard type is passed to setDate() so a UserType is not
+        # adopted by the QVariant which underpins the QAction data.  "guid"
+        # is a dbus.String object; it will be stored as a UserType if passed
+        # directly, which makes it difficult to extract in setTabVisible().
+        self.parent.devices[guid].setData(str(guid))
+        self.parent.editmenu.addAction(self.parent.devices[guid])
+        self.parent.devices[guid].triggered.connect(self.setTabVisible)
+    
+    def setTabVisible(self) :
+        action = self.sender()
+        # Extract the action data and store as a dbus.String type so 
+        # it is usable as a key into self.panels[].
+        panel_key = dbus.String(action.data().toString() if ffado_pyqt_version == 4 else action.data())
+        self.tabs.setCurrentIndex(self.tabs.indexOf(self.panels[panel_key]))
+
     def displayPanels(self):
         # if there is no panel, add the no-device message
         # else make sure it is not present
@@ -380,7 +417,10 @@ mixerwidget = ffado.mixer.%s.%s( w )
         guid_indexes = {}
         for idx in range(nbDevices):
             path = self.devmgr.getDeviceName(idx)
-            cfgrom = ConfigRomInterface(FFADO_DBUS_SERVER, FFADO_DBUS_BASEPATH+'/DeviceManager/'+path)
+            if ffado.config.bypassdbus:
+                cfgrom = ConfigRomInterface(FFADO_DBUS_SERVER, path)
+            else:
+                cfgrom = ConfigRomInterface(FFADO_DBUS_SERVER, FFADO_DBUS_BASEPATH+'/DeviceManager/'+path)
             guid = cfgrom.getGUID()
             guids_present.append(guid)
             guid_indexes[guid] = idx
@@ -471,10 +511,12 @@ mixerwidget = ffado.mixer.%s.%s( w )
           saveString.append('</device>\n')
         # file saving
         savefilename = QFileDialog.getSaveFileName(self, 'Save File', os.getenv('HOME'))
+        if isinstance(savefilename, tuple): # newer PyQt5
+            savefilename = savefilename[0]
         try:
           f = open(savefilename, 'w')
         except IOError:
-          print "Unable to open save file"
+          print( "Unable to open save file" )
           return
         for s in saveString:
           f.write(s)
@@ -482,10 +524,12 @@ mixerwidget = ffado.mixer.%s.%s( w )
 
     def readSettings(self):
         readfilename = QFileDialog.getOpenFileName(self, 'Open File', os.getenv('HOME'))
+        if isinstance(readfilename, tuple): # newer PyQt5
+            readfilename = readfilename[0]
         try:
           f = open(readfilename, 'r')
         except IOError:
-          print "Unable to open file"
+          print( "Unable to open file" )
           return
         log.debug("Opening file %s" % readfilename)
         # discard useless whitespace characters
@@ -496,28 +540,28 @@ mixerwidget = ffado.mixer.%s.%s( w )
         # Check it is a compatible "FFADO" file
         # It must start with the <?xml ... tag as the first string
         if readString[0].find("<?xml") == -1:
-            print "Not an xml data file"
+            print( "Not an xml data file" )
             return
         # Then there must be a file version tag somewhere in the file
         try:
             idx = readString.index('<fileversion>')
         except Exception:
-            print "Data file should contain the version tag"
+            print( "Data file should contain the version tag" )
             return
         if readString[idx+1].find("<major>") == -1:
-            print "Incompatible versioning of the file"
+            print( "Incompatible versioning of the file" )
         if readString[idx+3].find("</major>") == -1:
-            print "Not a valid xml file"
+            print( "Not a valid xml file" )
         if readString[idx+4].find("<minor>") == -1:
-            print "Incompatible versioning of the file"
+            print( "Incompatible versioning of the file" )
         if readString[idx+6].find("</minor>") == -1:
-            print "Not a valid xml file"
+            print( "Not a valid xml file" )
         version_major = readString[idx+2]
         version =  version_major + '.' + readString[idx+5]
         log.debug("File version: %s" % version)
         # File version newer than present
         if int(version_major) > int(str(FILE_VERSION).split('.')[0]):
-            print "File version is too recent: you should upgrade your FFADO installation"
+            print( "File version is too recent: you should upgrade your FFADO installation" )
             return
         # FIXME At a time it will be necessary to detect if an older major version is detected
         #
@@ -528,13 +572,13 @@ mixerwidget = ffado.mixer.%s.%s( w )
         nd = readString.count('<device>');
         n  = readString.count('</device>');
         if n != nd:
-            print "Not a regular xml file: opening device tag must match closing ones"
+            print( "Not a regular xml file: opening device tag must match closing ones" )
             return
         while nd > 0:
           idxb = readString.index('<device>')
           idxe = readString.index('</device>')
           if idxe < idxb+1:
-            print "Not a regular xml file: data must be enclosed between a <device> and </device> tag"
+            print( "Not a regular xml file: data must be enclosed between a <device> and </device> tag" )
             return
           stringDev = []
           for s in readString[idxb:idxe]:
@@ -543,7 +587,7 @@ mixerwidget = ffado.mixer.%s.%s( w )
           try:
               idx = stringDev.index('<guid>')
           except Exception:
-              print "Device guid not found"
+              print( "Device guid not found" )
               return
           guid = stringDev[idx+1]
           log.debug("Device %s found" % guid)
